--- libgo/go/net/sock_bsd.go.orig	2013-07-16 06:55:04 UTC
+++ libgo/go/net/sock_bsd.go
@@ -2,7 +2,7 @@
 // Use of this source code is governed by a BSD-style
 // license that can be found in the LICENSE file.
 
 // +build darwin freebsd netbsd openbsd
 
 package net
 
@@ -17,7 +17,7 @@ func maxListenerBacklog() int {
 		err error
 	)
 	switch runtime.GOOS {
-	case "darwin", "freebsd":
+	case "darwin", "freebsd", "bsdsunix":
 		n, err = syscall.SysctlUint32("kern.ipc.somaxconn")
 	case "netbsd":
 		// NOTE: NetBSD has no somaxconn-like kernel state so far
@@ -2,7 +2,7 @@
 // license that can be found in the LICENSE file.
 
-// +build darwin freebsd netbsd openbsd
+// +build darwin freebsd netbsd openbsd bsdsunix
 
 package net